@@ -7,7 +7,7 @@ including getting child elements, parents, siblings, and cousins.
 from __future__ import annotations
 
 import logging
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Literal
 
 from selenium.webdriver.support import expected_conditions
 from selenium.webdriver.support.wait import WebDriverWait
@@ -122,6 +122,7 @@ class ElementDOM:
         timeout: float = 30,
         poll_frequency: float = 0.5,
         ignored_exceptions: WaitExcTypes | None = None,
+        exclude_attributes: tuple[str, ...] = (),
     ) -> list[Element]:
         """Get multiple child elements relative to the current element.
 
@@ -130,6 +131,7 @@ class ElementDOM:
             timeout: Maximum time to wait for elements.
             poll_frequency: How often to check for elements.
             ignored_exceptions: Exceptions to ignore during wait.
+            exclude_attributes: Attributes to exclude from xpath when finding elements.
 
         Returns:
             List of found child elements.
@@ -165,8 +167,12 @@ class ElementDOM:
         )
         elements: list[Element] = []
         for attributes in attributes_list:
+            cleared_attributes = attributes.copy()
+            for exclude_attribute in exclude_attributes:
+                if exclude_attribute in attributes:
+                    cleared_attributes.pop(exclude_attribute)
             element = Element(  # type: ignore[return-value]
-                locator=attributes,
+                locator=cleared_attributes,
                 shadowstep=self.shadowstep,
                 timeout=timeout,
                 poll_frequency=poll_frequency,
@@ -239,6 +245,7 @@ class ElementDOM:
         timeout: float = 30.0,
         poll_frequency: float = 0.5,
         ignored_exceptions: WaitExcTypes | None = None,
+        strategy: Literal["following", "preceding"] = "following",
     ) -> Element:
         """Get a sibling element of the current element.
 
@@ -247,6 +254,7 @@ class ElementDOM:
             timeout: Maximum time to wait for element.
             poll_frequency: How often to check for element.
             ignored_exceptions: Exceptions to ignore during wait.
+            strategy: Strategy to search for. Following - after, preceding - before current element.
 
         Returns:
             The found sibling element.
@@ -259,7 +267,7 @@ class ElementDOM:
         sibling_locator = self.utilities.remove_null_value(locator)
         sibling_xpath = self.converter.to_xpath(sibling_locator)
         sibling_path = sibling_xpath[1].lstrip("/")
-        xpath = f"{base_xpath}/following-sibling::{sibling_path}[1]"
+        xpath = f"{base_xpath}/{strategy}-sibling::{sibling_path}[1]"
         return Element(  # type: ignore[return-value]
             locator=("xpath", xpath),
             shadowstep=self.shadowstep,
@@ -275,6 +283,7 @@ class ElementDOM:
         timeout: float = 30.0,
         poll_frequency: float = 0.5,
         ignored_exceptions: WaitExcTypes | None = None,
+        strategy: Literal["following", "preceding"] = "following",
     ) -> list[Element]:
         """Get all sibling elements of the current element.
 
@@ -283,6 +292,7 @@ class ElementDOM:
             timeout: Maximum time to wait for elements.
             poll_frequency: How often to check for elements.
             ignored_exceptions: Exceptions to ignore during wait.
+            strategy: Strategy to search for. Following - after, preceding - before current element.
 
         Returns:
             List of found sibling elements.
@@ -293,7 +303,7 @@ class ElementDOM:
         sibling_locator = self.utilities.remove_null_value(locator)
         sibling_xpath = self.converter.to_xpath(sibling_locator)
         sibling_path = sibling_xpath[1].lstrip("/")
-        xpath = f"{base_xpath}/following-sibling::{sibling_path}"
+        xpath = f"{base_xpath}/{strategy}-sibling::{sibling_path}"
         return self.get_elements(("xpath", xpath), timeout, poll_frequency, ignored_exceptions)
 
     @log_debug()
